@@ -81,3 +81,24 @@ def test_api_with_requirement_file():
         expected_file=expected_file,
         clean=True,
     )
+
+
+def test_api_with_prefer_source():
+    result_file = test_env.get_temp_file("json")
+    expected_file = test_env.get_test_loc("test-api-with-prefer-source.json", must_exist=False)
+    with open(result_file, "w") as result:
+        result.write(
+            json.dumps(
+                resolver_api(
+                    specifiers=["flask==2.1.2"],
+                    python_version="3.10",
+                    operating_system="linux",
+                    prefer_source=True,
+                ).to_dict()
+            )
+        )
+    check_json_results(
+        result_file=result_file,
+        expected_file=expected_file,
+        clean=True,
+    )
